
# Welcome to ScalarPy!

## Scalarpy is an open-source Auto-ML library that automates the machine learning work flow starting from Data pre-processing to model deployment and simplifies your machine learning flow.